@@ -2,13 +2,8 @@ import sys
 import warnings
 if not sys.warnoptions:
     warnings.simplefilter("ignore")
-
 from typing import Callable
 
-import pandas as pd
-import numpy as np
-import matplotlib.pyplot as plt
-
 
 from . import nans
 from . import encoder
@@ -28,6 +23,9 @@ from . import save_load_algorithms
 # from itertools import chain, combinations
 # from multiprocessing import Pool, cpu_count
 
+# import pandas as pd
+# import numpy as np
+# import matplotlib.pyplot as plt
 # import lightgbm as lgb
 # from sklearn.model_selection import train_test_split
 # from sklearn.metrics import mean_absolute_error, mean_squared_error, r2_score
